@echo off

REM die Batch-Datei muss im selben Ordner liegen, wie die DGM-Kacheln
set pathToDGM=%~dp0
set tmpFolder=tmp

cd %pathToDGM:~0,-1%
if not exist %tmpFolder% (
  md %tmpFolder%
)

REM erzeuge virtuelles Raster-Mosaik aus allen XYZ-Dateien
gdalbuildvrt ^
  -vrtnodata -9999 ^
  dgm01.vrt ^
  *.xyz

REM erzeuge DEFLATE-komprimiertes TIFF mit interner Kachelung
gdal_translate ^
  dgm01.vrt %tmpFolder%/dgm01.tif ^
  -stats ^
  -ot Float32 -r nearest ^
  -of GTiff -co BIGTIFF=YES ^
  -co COMPRESS=DEFLATE -co NUM_THREADS=ALL_CPUS ^
  -co TILED=YES -co BLOCKXSIZE=512 -co BLOCKYSIZE=512 -co SPARSE_OK=TRUE

REM erzeuge TIFF-interne Übersichten
gdaladdo ^
  -r gauss ^
  -minsize 512 ^
  --config GDAL_TIFF_OVR_BLOCKSIZE 512 ^
  --config COMPRESS_OVERVIEW DEFLATE ^
  %tmpFolder%/dgm01.tif

gdalinfo %tmpFolder%/dgm01.tif

REM erzeuge Schummerung
(
  start "hillshade 315" ^
    gdaldem hillshade ^
      dgm01.vrt ^
      %tmpFolder%/01_hs_315.tif ^
      -az 315 -alt 35 -z 1.5 ^
      -compute_edges ^
      -of GTiff -co BIGTIFF=YES

  start "hillshade 22" ^
    gdaldem hillshade ^
      dgm01.vrt ^
      %tmpFolder%/02_hs_22.tif ^
      -az 22 -alt 35 -z 1.5 ^
      -compute_edges ^
      -of GTiff -co BIGTIFF=YES

  start "hillshade 90" ^
    gdaldem hillshade ^
      dgm01.vrt ^
      %tmpFolder%/03_hs_90.tif ^
      -az 90 -alt 35 -z 1.5 ^
      -compute_edges ^
      -of GTiff -co BIGTIFF=YES
) | pause >nul

REM füge Schummerungen zusammen
gdalbuildvrt ^
  -separate ^
  %tmpFolder%/rgb.vrt ^
  %tmpFolder%/01_hs_315.tif ^
  %tmpFolder%/02_hs_22.tif ^
  %tmpFolder%/03_hs_90.tif

REM erzeuge JPEG-komprimiertes TIFF mit interner Kachelung
gdal_translate ^
  %tmpFolder%/rgb.vrt %tmpFolder%/dgm01_hs_rgb.tif ^
  -b 1 -b 2 -b 3 ^
  -a_nodata none -colorinterp red,green,blue -stats ^
  -of GTiff -co BIGTIFF=YES ^
  -co COMPRESS=JPEG -co JPEG_QUALITY=85 -co PHOTOMETRIC=YCBCR ^
  -co TILED=YES -co BLOCKXSIZE=512 -co BLOCKYSIZE=512 -co SPARSE_OK=TRUE

REM erzeuge TIFF-interne Übersichten
gdaladdo ^
  -r gauss ^
  -minsize 512 ^
  --config GDAL_TIFF_OVR_BLOCKSIZE 512 ^
  --config COMPRESS_OVERVIEW JPEG ^
  --config JPEG_QUALITY_OVERVIEW 85 ^
  --config PHOTOMETRIC_OVERVIEW YCBCR ^
  %tmpFolder%/dgm01_hs_rgb.tif

gdalinfo %tmpFolder%/dgm01_hs_rgb.tif

REM erzeuge Geländeneigung
gdaldem slope ^
  dgm01.vrt ^
  %tmpFolder%/slope.tif ^
  -compute_edges ^
  -of GTiff -co BIGTIFF=YES ^
  -co COMPRESS=DEFLATE

REM Skaliere Float32 (0.0° bis 90.0°) zu Byte (0 bis 255) wegen Dateigröße
gdal_translate ^
  %tmpFolder%/slope.tif %tmpFolder%/dgm01_slope.tif ^
  -stats -ot Byte -of GTiff -scale 0 90 ^
  -co TILED=YES -co BLOCKXSIZE=512 -co BLOCKYSIZE=512 -co SPARSE_OK=TRUE ^
  -co COMPRESS=JPEG -co JPEG_QUALITY=85

REM erzeuge TIFF-interne Übersichten
gdaladdo ^
  -r gauss ^
  -minsize 512 ^
  --config GDAL_TIFF_OVR_BLOCKSIZE 512 ^
  --config COMPRESS_OVERVIEW JPEG ^
  --config JPEG_QUALITY_OVERVIEW 85 ^
  %tmpFolder%/dgm01_slope.tif

gdalinfo %tmpFolder%/dgm01_slope.tif